@@ -1,6 +1,6 @@
-/**
+/* wni.c
  * Artha - Free cross-platform open thesaurus
- * Copyright (C) 2009  Sundaram Ramaswamy, legends2k@yahoo.com
+ * Copyright (C) 2009, 2010  Sundaram Ramaswamy, legends2k@yahoo.com
  *
  * Artha is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -13,22 +13,30 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Artha; if not, see <http://www.gnu.org/licenses/>.
+ * along with Artha; if not, write to the Free Software Foundation, Inc., 
+ * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
- 
-/*
-   wni.c: WordNet Interface module, which does the actual talking to 
-   libwordnet. Sits b/w the application and the wordnet database files, 
-   receives requests for a given search string, if found in WordNet, 
-   populates the requested lists.
 
-   TODO: When in simple mode, see pertainyms of 'verbally' and hypernyms of 'conquest', 
-   should, duplicate check for them in these simple mode case, be done? Likewise, see 
-   'rupee's Meronyms in Simple mode, it lists cent and paise around 5 times!
+
+/*
+ * WordNet Interface code
+ * This does the actual talking to libwordnet. Sits b/w the application 
+ * and the wordnet database files, receives requests for a given search 
+ * string, if found in WordNet, populates the requested lists.
+ */
+
+
+/*
+   TODO: When in simple mode, see pertainyms of 'verbally' and hypernyms of
+   'conquest'; Should duplicate check for them in these simple mode cas be 
+   done? Likewise, see 'rupee' Meronyms in Simple mode, it lists cent and 
+   paise around 5 times!
 */
 
-#include "wni.h"
 
+#include <string.h>
+#include <wn.h>
+#include "wni.h"
 
 // WNI Global Variable
 GSList *global_list = NULL;
@@ -100,12 +108,13 @@ int wni_strcmp0(const char *s1, const char *s2)
 
 static int depth_check(guint8 depth, SynsetPtr synptr)
 {
-    if(depth >= MAXDEPTH)
-    {
-	g_error("WordNet library error: Error Cycle detected\n   %s\n", synptr->words[0]);
-	depth = -1;		/* reset to get one more trace then quit */
-    }
-    return(depth);
+	if(depth >= MAXDEPTH)
+	{
+		g_warning("WordNet library error: Error Cycle detected\n%s\n", synptr->words[0]);
+		depth = -1;		/* reset to get one more trace then quit */
+	}
+
+	return(depth);
 }
 
 
@@ -459,7 +468,7 @@ static gchar* parse_definition(gchar *str)
 	guint16 i = 0, len = 0;
 	guint8 brace_met = FALSE;
 	guint8 double_quotes_met = 0;
-	guint8 just_ended = FALSE;
+	gboolean just_ended = FALSE;
 	gchar ch = 0;
 	gchar *temp_ch = NULL;
 
@@ -1082,6 +1091,7 @@ static void grow_tree(gchar *lemma, SynsetPtr synptr, guint8 ptr, GNode **root,
 					node_list = g_slist_prepend(node_list, implication);
 				//}
 			}
+
 			if(node_list)
 			{
 				//tree_list = (WNITreeList*) g_malloc0(sizeof(WNITreeList));
@@ -1098,6 +1108,7 @@ static void grow_tree(gchar *lemma, SynsetPtr synptr, guint8 ptr, GNode **root,
 					grow_tree(lemma, cursyn, HYPERPTR, &cur_tree, depth);
 				}
 			}
+
 			if(depth && cur_tree != NULL)
 			{
 				depth = depth_check(depth, cursyn);
@@ -1190,6 +1201,7 @@ static void trace_inherit(gchar *lemma, SynsetPtr synptr, GNode **root, guint8 d
 					}
 				}
 			}
+
 			free_synset(cursyn);
 		}
 	}
@@ -1592,7 +1604,7 @@ static void definitions_free(GSList **list)
 
 	while(temp_list)
 	{
-		if(temp_list->data);
+		if(temp_list->data)
 		{
 			temp_def = (WNIDefinition*) temp_list->data;
 			G_PRINTF("(%d) %s\n", temp_def->tag_count, temp_def->definition);
